@@ -5,7 +5,7 @@ function(node)
     nodeName <- sQuote(node)
     command <- paste("SamplesEmbed.SetVariable(", nodeName, 
                             ");SamplesEmbed.HistoryGuard;SamplesEmbed.Clear")
-    .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
+    .CmdInterpreter(command)
     if(getOption("BRugsVerbose")) 
         buffer()
 }
