@@ -4,20 +4,21 @@ function(node)
 {
     nodeName <- sQuote(node)
     for(i in seq(along=nodeName)){
-        sM <- paste(samplesMonitors(node[i]), collapse = " ")
+        sM <- paste(suppressMessages(samplesMonitors(node[i])), collapse = " ")
         if(sM == "model must be initialized before monitors used")
             stop("model must be initialized before monitors used")
-        if(sM == "inference can not be made when sampler is in adaptive phase")
+        if(sM %in% c("inference can not be made when sampler is in adaptive phase",
+                     "model has probably not yet been updated"))
             alreadySet <- FALSE
-        else 
+        else
             alreadySet <- !length(grep("no monitor set", sM))
         eval(alreadySet)
-        command <- paste("SamplesEmbed.SetVariable(", nodeName[i], 
+        command <- paste("SamplesEmbed.SetVariable(", nodeName[i],
                                 ");SamplesEmbed.SetGuard;SamplesEmbed.Set")
-        .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
+        .CmdInterpreter(command)
         buffer <- file.path(tempdir(), "buffer.txt")
         rlb <- readLines(buffer)
-        if(rlb == "") 
+        if(rlb == "")
             message("either model has not been updated or variable ", nodeName[i], " already set")
         else{
             if(getOption("BRugsVerbose")){
