@@ -6,7 +6,7 @@ function(node)
     for(i in seq(along=nodeName)){
         command <- paste("SummaryEmbed.SetVariable(", nodeName[i], "); SummaryEmbed.StatsGuard;",
                          "SummaryEmbed.Clear")
-        .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
+        .CmdInterpreter(command)
         buffer <- file.path(tempdir(), "buffer.txt")
         rlb <- readLines(buffer)
         if(getOption("BRugsVerbose"))
